@@ -7,9 +7,12 @@ mod use_is_mounted;
 mod use_latest;
 mod use_list;
 mod use_local_storage;
+mod use_map;
 mod use_mount;
 mod use_previous;
+mod use_queue;
 mod use_session_storage;
+mod use_set;
 mod use_timeout;
 mod use_title;
 mod use_toggle;
@@ -25,9 +28,12 @@ pub use use_is_mounted::*;
 pub use use_latest::*;
 pub use use_list::*;
 pub use use_local_storage::*;
+pub use use_map::*;
 pub use use_mount::*;
 pub use use_previous::*;
+pub use use_queue::*;
 pub use use_session_storage::*;
+pub use use_set::*;
 pub use use_timeout::*;
 pub use use_title::*;
 pub use use_toggle::*;
